document.addEventListener('DOMContentLoaded', function() {
    const dropArea = document.getElementById('drop-area');
    const fileInput = document.getElementById('fileInput');
    const dropAreaText = dropArea.querySelector('p');
    const md5Display = document.getElementById('md5');
    const sha1Display = document.getElementById('sha1');
    const sha256Display = document.getElementById('sha256');

    dropArea.addEventListener('dragover', (event) => {
        event.preventDefault();
        dropArea.classList.add('dragging');
    });

    dropArea.addEventListener('dragleave', () => {
        dropArea.classList.remove('dragging');
    });

    dropArea.addEventListener('drop', (event) => {
        event.preventDefault();
        dropArea.classList.remove('dragging');
        const files = event.dataTransfer.files;
        if (files.length > 0) {
            handleFile(files[0]);
        }
    });

    dropArea.addEventListener('click', () => {
        fileInput.click();
    });

    fileInput.addEventListener('change', (event) => {
        const files = event.target.files;
        if (files.length > 0) {
            handleFile(files[0]);
        }
    });

    function handleFile(file) {
        dropAreaText.textContent = `选中文件: ${file.name}`;

        const reader = new FileReader();
        reader.onload = (event) => {
            const data = event.target.result;
            calculateHashes(data);
        };
        reader.readAsArrayBuffer(file);
    }

    function calculateHashes(data) {
        const spark = new SparkMD5.ArrayBuffer();
        spark.append(data);
        const md5 = spark.end();

        const sha1 = sha1ArrayBuffer(data);
        const sha256 = sha256ArrayBuffer(data);

        md5Display.textContent = `MD5: ${md5}`;
        sha1Display.textContent = `SHA-1: ${sha1}`;
        sha256Display.textContent = `SHA-256: ${sha256}`;
    }

    function sha1ArrayBuffer(data) {
        const hash = CryptoJS.SHA1(CryptoJS.lib.WordArray.create(data));
        return hash.toString(CryptoJS.enc.Hex);
    }

    function sha256ArrayBuffer(data) {
        const hash = CryptoJS.SHA256(CryptoJS.lib.WordArray.create(data));
        return hash.toString(CryptoJS.enc.Hex);
    }
});
